@@ -8,9 +8,9 @@
 #include "radeon_probe.h"
 #include <X11/extensions/Xv.h>
 #include "radeon_video.h"
+#include "atipciids.h"
 
 #include "xf86.h"
-#include "xf86PciInfo.h"
 
 /* i2c stuff */
 #include "xf86i2c.h"
